@@ -17,7 +17,7 @@ cat << 'EEE' > /dev/null
  */
 EEE
 
-set -eu
+set -eux
 (
 # extend.sh dst ... dstにソースを展開する。
 pdir=`pwd`	#parent, callsrc dir
@@ -30,16 +30,17 @@ cd ./seed
 # copy, extend, delete
 # buf=`ls *.lua||:`
 # [ ${#buf} = 0 ] || (for ii in $buf; do cp $ii ../src;done)
-buf=`ls *.sh.c||:`
-[ ${#buf} = 0 ] || (for ii in $buf; do cp $ii ../src;done)
-
+buf=`ls [!_]*||:`
+[ ${#buf} = 0 ]&&exit 0 || (for ii in $buf; do cp -f $ii ../src;done)
 cd ../src
-for ii in *.sh.c; do
+buf=`ls *.sh.*||:`
+set -- $buf
+for ii ; do
 	sh "$ii" -W
 done
 # rf系が失敗するので再実行
-for ii in *.sh.c; do
+for ii ; do
 	sh "$ii" -W
 done
-rm *.tmp.c *.ts.c *.sh.c 2>/dev/null|| :
+rm *.tmp.* *.ts.* *.sh.* 2>/dev/null|| :
 )
