@@ -17,16 +17,10 @@ cat << 'EEE' > /dev/null
  */
 EEE
 
-set -eu
+set -eux
 (
 cd `dirname $0`
 sh ./extract.sh
 sh ./prebuild.sh		#updが展開済みソースが必要だから。
 sh ./upd.sh
-
-# other
-	#cd "../seed"
-	#for i in *.h ;do
-		#cp $i ../src
-	#done
 )
