@@ -73,15 +73,16 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 @_name	HCUT_ADD, HCUT_RUN, eq, eq_s/i/d/p
 @auther momi-g
 @brief	C Unit Test, portable unittest implemented in 1 header file
-@_synopsys
+@_syno
 	void HCUT_ADD(fcname)
 	int HCUT_RUN(const char* logfile, int msglv [, fcnames ...] )
-	void eq(int cmp)
-	void eq_s(void* s1, void* s2)
-	void eq_i(int i1, int i2)
-	void eq_d(double d1, double d2)
-	void eq_p(void* p1, void* p2)
-	... all eq funcs can take lastarg as cmt, eq_i(1,2, "failtest_cmt") etc. 
+	//assert macros, expand to 'do{...}while(0)'
+	eq(int cmp)
+	eq_s(void* s1, void* s2)
+	eq_i(int i1, int i2)
+	eq_d(double d1, double d2)
+	eq_p(void* p1, void* p2)
+	... all asserts can take lastarg as cmt, eq_i(1,2, "failtest_cmt") etc. 
 @_eg
 	#include <stdio.h>
 	#include "hcut.h"		//header holds all implements 
@@ -91,7 +92,7 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 	}
 	HCUT_ADD(anyname_hw) {
 		int ck = 123;
-		eq( hw()==10 );
+		eq( hw()==10 );	//== do{errck_eq(); if...;...}while(0)
 		eq_i( hw(), 100, "mycmt" );
 		printf("bin:%s\n", argv[0]);
 	}
@@ -111,16 +112,16 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 
 @param fcname	testfunc(test suite) name.  
 @param logfile msgout fname. "stdout","stderr","NULL" are used as FILE* / noout.
-@param lv	verbose lv. 0/1/2 ... quiet/normal/verbose.
+@param lv	verbose lv. 0/1/2/3. quiet/normal/verbose/verbose+stop if err
 @param fcname1,2-	test tgt. use as funcptr. test all suite you set here
-@return		HCUT_RUN() returns failed assert cnt. rtn -1 if err.
+@return		HCUT_RUN() returns failed assert cnt. rtn -1 if fatal err.
 @details	HCUT_RUN() holds "int main(int argc, char** argv){...}" func.
  you can use cmdin data 'argc/argv' in HCUR_ADD() block.
 @_note	other sample src is at srcend.
  https://sourceforge.net/projects/cutest/files/cutest/1.5/
  https://en.wikipedia.org/wiki/List_of_unit_testing_frameworks
-@_conforming c99+
-@version 2021-07-10 v1.2.7
+@conforming_to c99+
+@_ver 2021-11-30 v1.3.0
 -*/
 
 // change... sed -i 'HCUT_9611a28d' 'some_new_prefix_str'
@@ -140,30 +141,32 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 #endif
 #include <string.h>
 #include <errno.h>
-#define HCUT_Eact(xpr, msg, act)	if(xpr){ fprintf(stderr, \
+#define HCUT_Eact(xpr, msg, act)	if(xpr){ int en_=errno; fprintf(stderr, \
 	"ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, HCUT_Eactag \
-	, "hit(" #xpr ")", msg, strerror(errno) ); act; }
+	, "hit(" #xpr ")", msg, strerror(en_) ); act; }
 
 //api_macro...see this srcend sample
 #define HCUT_ADD(a)		HCUT_9611a28d_ADD(a)
-#define HCUT_RUN(...)	HCUT_9611a28d_RUN(__VA_ARGS__)	
-#define eq(...)		HCUT_9611a28d_assert_eq_sub(__VA_ARGS__, 0)
+#define HCUT_RUN(...)	HCUT_9611a28d_RUN(__VA_ARGS__)
+#define HCUT_9611a28d_BACK	if(HCUT_9611a28d_cmn.outlv==3&&HCUT_9611a28d_cmn.fail){return;}
+
+#define eq(...)		do{HCUT_9611a28d_assert_eq_sub(__VA_ARGS__, 0);HCUT_9611a28d_BACK}while(0)
 #define HCUT_9611a28d_assert_eq_sub(a, ...)	\
 	HCUT_9611a28d_assert_eq(__FILE__, __LINE__, #a, !!(a), 1, __VA_ARGS__)
 
-#define eq_s(...)	HCUT_9611a28d_assert_eqs_sub(__VA_ARGS__, 0)
+#define eq_s(...)	do{HCUT_9611a28d_assert_eqs_sub(__VA_ARGS__, 0);HCUT_9611a28d_BACK}while(0)
 #define HCUT_9611a28d_assert_eqs_sub(a, b, ...)	\
 	HCUT_9611a28d_assert_eqs(__FILE__, __LINE__, #a ", " #b, a, b, __VA_ARGS__)
 
-#define eq_i(...)	HCUT_9611a28d_assert_eqi_sub(__VA_ARGS__, 0)
+#define eq_i(...)	do{HCUT_9611a28d_assert_eqi_sub(__VA_ARGS__, 0);HCUT_9611a28d_BACK}while(0)
 #define HCUT_9611a28d_assert_eqi_sub(a, b, ...)	\
 	HCUT_9611a28d_assert_eqi(__FILE__, __LINE__, #a ", " #b, (int)a, (int)b, __VA_ARGS__)
 
-#define eq_d(...)	HCUT_9611a28d_assert_eqd_sub(__VA_ARGS__, 0)
+#define eq_d(...)	do{HCUT_9611a28d_assert_eqd_sub(__VA_ARGS__, 0);HCUT_9611a28d_BACK}while(0)
 #define HCUT_9611a28d_assert_eqd_sub(a, b, ...)	\
 	HCUT_9611a28d_assert_eqd(__FILE__, __LINE__, #a ", " #b, (double)a, (double)b, __VA_ARGS__)
 
-#define eq_p(...)	HCUT_9611a28d_assert_eqp_sub(__VA_ARGS__, 0)
+#define eq_p(...)	do{HCUT_9611a28d_assert_eqp_sub(__VA_ARGS__, 0);HCUT_9611a28d_BACK}while(0)
 #define HCUT_9611a28d_assert_eqp_sub(a, b, ...)	\
 	HCUT_9611a28d_assert_eqp(__FILE__, __LINE__, #a ", " #b, (char*)a, (char*)b, __VA_ARGS__)
 
@@ -209,7 +212,7 @@ int HCUT_9611a28d_pf(int lv, const char* fmt, ...){
 typedef void (*HCUT_9611a28d_tf_t)(int argc, char** argv);
 int HCUT_9611a28d_run(const char* out, int lv, HCUT_9611a28d_tf_t* tfarr, int argc, char** argv) {
 	FILE* fp=NULL;
-	; HCUT_Eact(lv<0||2<lv, "verboseLv allows only 0,1,2" , exit(-1) );
+	; HCUT_Eact(lv<0||3<lv, "verboseLv allows only 0,1,2,3" , exit(-1) );
 	if(strcmp(out, "stdout")==0 ){ HCUT_9611a28d_cmn.fp = stdout;}
 	else if(strcmp(out, "stderr")==0 ){ HCUT_9611a28d_cmn.fp = stderr;}
 	else if(strcmp(out, "NULL")==0 ){ HCUT_9611a28d_cmn.fp = NULL;}
@@ -220,7 +223,13 @@ int HCUT_9611a28d_run(const char* out, int lv, HCUT_9611a28d_tf_t* tfarr, int ar
 	}
 	HCUT_9611a28d_cmn.outlv = lv;
 	int i;
-	for(i=0; tfarr[i]!=NULL; i++){ tfarr[i](argc, argv); }
+	for(i=0; tfarr[i]!=NULL; i++){
+		tfarr[i](argc, argv);
+		if(lv==3&&HCUT_9611a28d_cmn.fail){
+			HCUT_9611a28d_pf(1, "detect test err & stop mode\n");
+			break;
+		}
+	}
 	HCUT_9611a28d_pf(1, "fail/all: %d/%d\n", HCUT_9611a28d_cmn.fail
 		, HCUT_9611a28d_cmn.fail + HCUT_9611a28d_cmn.suc);
 	if(fp){fclose(fp);}
@@ -287,6 +296,7 @@ void HCUT_9611a28d_assert_eqp(const char* flname, int lnum
 #include "hcut.h"
 HCUT_ADD(t_hcut) {
 	eq_i(1,2,"errck");
+	eq_i(1,1,"errck");
 }
 #endif
 
@@ -325,19 +335,25 @@ HCUT_RUN("stderr", 1, t_hw, test_gw12345 )
 
 // HCUT_RUN() holds "int main(int argc, char** argv){..}" and returns fail cnt.
 // arg1 : msgout filename. "stdout","stderr","NULL" are used as FILE* or noout. 
-// arg2 : verbose lv. 0/1/2 ... quiet/normal/verbose 
+// arg2 : verbose lv. 0/1/2/3 ... quiet/normal/verbose/stop
 // arg3-: test all suite you set here.  (use ~$ sed -ne '/^HCUT/{=;p}' test.c)
 // rtn/exit status: cnt of failed assert. rtn -1 if fatal err.
 //SH_SMPE*/
 
 #ifdef TEST
-HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
+HCUT_RUN("stderr", 3,	/* keep newline. use for SH sed edit, -t test.*/
   t_hcut);
 #endif
 
 /*
  change log
  --
+2021-11-30	Momi-g	<dmy@dmy.dmy>
+	
+	* hcut.sh.c(HCUT_RUN): add lv==3, stop if fail. v1.3.0
+	* (HCUT..._BACK): add macro for lv==3 stop
+	* (eq asserts): change macro expr >> statement for lv==3
+
 2021-07-10	Momi-g	<dmy@dmy.dmy>
 	
 	* hcut.sh.c(HCUT_RUN): add *p=NULL, stop valgrind mem warning
@@ -418,12 +434,12 @@ HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
 */
 /*SH_ED*/
 
-/*SH_OP _ set -e;a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a"	#*/
+/*SH_OP _ set -e;a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a";set +e	#*/
 /*SH_OP	h $p"-tsbS:test/eg/.o/.so -LMP:leak,mem,prof -f:funcs -o:bldout		GPLv3+"	 #*/
-/*SH_OP	f sed -ne "/${C}DF/q;/;/d;/^[a-z].*)/p"<$R0 #*/
-/*SH_OP t $e"$CW";ftt "$@";$p'cc -O0 -Wall -pedantic -g -pg -ggdb3 $tf $Rs `fOI $Rs $tf` `fg $Rs $tf` `fL`'|fv	#*/
-/*SH_OP T $e"$CW";ftt "$@";$p'cc -O2 $tf $Rs `fOI $Rs $tf ` `fg $Rs $tf ` `fL`'|fv	#*/
-/*SH_OP s $e"$CB";fgr0 "${C}SMP" "${C}SMPE"<$Rs|fbn>eg.c;$p'cc eg.c `fg eg.c`'|fv #*/
+/*SH_OP	f sed -ne "/${C}DF/q;/;/d;/^[a-zA-Z].*)/p"<$R0 #*/
+/*SH_OP t $e"$CW";ftt "$@";$p'cc -O0 -static -Wall -pedantic -g -pg -ggdb3 $Rm `fOI $Rs $tf` `fg $Rs $tf` `fL`'|fv	#*/
+/*SH_OP T $e"$CW";ftt "$@";$p'cc -O3 $Rm `fOI $Rs $tf ` `fg $Rs $tf ` `fL`'|fv	#*/
+/*SH_OP s $e"$CB";fgr0 "${C}SMP" "${C}SMPE"<$Rs|fbn>eg.c;$p'cc eg.c `fg eg.c` `fOI eg.c`'|fv #*/
 
 /*SH_OP L $p"valgrind --leak-check=full --show-leak-kinds=all --track-origins=yes --verbose ./a.out 2>&1|sed -e '/SUMMA/!d;n;n;n;n'"|fv #*/
 /*SH_OP M $p"fM ./a.out"|fv	 #*/
@@ -433,22 +449,18 @@ HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
 /*SH_OP B $e"$Cb";$p"ar -r lib$bn.a $bn.o `fO $Rs`"|fv;$p"lib$bn.a"	#*/
 /*SH_OP A $e"$CB";$p'fA lib$bn.a `fg $Rh $Rs|fu|grep '[.]a$'|fU`'|fv;$p"lib$bn.a" #*/
 /*SH_OP S $e"$Cb";$p"cc -shared -fPIC -o lib$bn.so $bn.o `fOI $Rs` `fg $Rs`"|fv;$p"lib$bn.so" #*/
-/*SH_OP W $e"$Cm$O$Cw">/dev/null;$i0;$i1;$p"$Rs $Rh $tf"	#*/
-/*SH_OP o $e"$CW";$p"rm $tf"|fv;fman $R0 3	#*/
+/*SH_OP W $e"$Cm$O$Cw">/dev/null;fborn;$p"$Rs $Rh $tf"	#*/
+
+/*SH_OP o $e"$CW";$p'fman $Rh 3'|fv		#*/
 
 /*SH_DF
 #-- noob
-fman()(fgr0 "${C}doc" "${C}docE"<$1>$Rm
-cat $Rm|sed -e's/^@\([_a-zA-Z][_[:alnum:]]*\)/\n\n# \1\n\n/g
-/^\\/{s/^\\/<br>/g}'>$bn.md
-cat $bn.md|pandoc -f markdown -thtml> $Rm
-cat $Rm|pandoc -s -f html -t man -M title="$bn" -M section="$2" \
--M date=`date '+%Y-%m-%d'` > $bn.$2
-sed -e 's/^.nf/.RE\n.nf/'<$bn.$2>$Rm
-mv $Rm $bn.$2
-fhtml
+fman()( $p"fgr0 '${C}doc' '${C}docE'<$1|amn >$bn.$2
+ mandoc -Thtml <$bn.$2 >$bn.$2.html
+ #fgr0 '${C}doc' '${C}docE'<$1|amn -Dzwsp=1 >$Rm
+ #man -Tutf8 /dev/stdin<$Rm|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt
+ "|fv
 )
-fhtml()( md2h $bn.md $bn )
 
 #-- local
 
@@ -457,7 +469,7 @@ bn=`basename ${Rs%.*}`; tf=${Rs%/*}/${bn}.ts.${Rs##*.}; e="eval "; p="$Rp"
 #-- mod
 fv()(while read -r a;do $e"cat<<E$O# $a${O}E"|sed -e 's@-L.*-L[^ ]*@-L(omit)@g'>/dev/stderr;$e"$a";done)
 
-fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frf)
+fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frf|frv|flit)
 fsn()(tr -s ' \t' '\n')
 fsl()(tr -s '\n' ' ')
 fu()(fsn|sort -u)
@@ -539,21 +551,32 @@ EEE
 
 #-- longcmd
 frf()(
- awk -v r="${C##*]}rf" 'match($0,r){
- s=substr($0, RSTART+RLENGTH+1)
- gsub(/.[^*]*$/, "", s);split(s, a)
- m="[ -f %s ]&&echo \"/*--copyfrom %s*\"/&&cat %s&&echo \"/*--copyend %s*\"/"
- for(i=1;v=a[i];i++){ system( sprintf(m, v,v,v,v))}
+ # *sh_rf* 0 a.txt b.txt ...でcat纏めて出力 top0でsrcinfoは無し出力
+ awk -v tg="${C##*]}rf" 'index($0,tg){
+ s=substr($0, index($0,tg)+length(tg)+1);split(s, a)
+ m="[ -f \"%s\" ]&&(echo \"/*--copyfrom %s*\"/;cat \"%s\";echo \"/*--copyend %s*\"/)"
+ mm="[ -f \"%s\" ]&&(_=\"%s\"/;cat \"%s\";_=\"%s\")"
+ for(i=1;i in a;i++){v=a[i];if(v==0){m=mm;continue};system(sprintf(m,v,v,v,v)) }
  next
  }
  {print}'
 )
+frv()(buf=`awk '$1=="@_ver" {print $3;exit}'<$R0`;sed -e "s@\*${C##*]}ver\*@$buf@g")
+flit()(sed -ne "/${C}lit/bl;p;d;:l;n;/${C}litE/d;"'s/[\]/&&/g;s/"/\\"/g;s@.*@"&\\n"@g;p;bl')
 
-ftt()(a="`sed -ne 's@^HCUT_ADD(\([^)]*\).*@\1, @p' $tf|tr -d '\n'`NULL"
-	if [ $# != 0 ];then	a=""; for i;do a="$a $i,";done; a="$a NULL"; fi
-	sed -ne "p;/_RUN/bl;d;:l;/[)]/{c\\$O $a)$O p;d};n;bl"<$tf>$Rm;mv $Rm $tf)
-i0=$e'fgr0 "^#ifdef TEST" "^#endif"<$R0|fbn>$tf'
-i1=$e'fgR "^#ifdef TEST" "^#endif"<$Rs|fbn>$Rm;mv $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh'
+fte(){
+ cat > $Rm-
+ a="`sed -ne 's@^HCUT_ADD(\([^)]*\).*@\1, @p' $Rm-|tr -d '\n'`NULL"
+ if [ $# != 0 ];then	a=""; for i;do a="$a $i,";done; a="$a NULL"; fi
+ sed -ne "p;/_RUN/bl;d;:l;/[)]/{c\\$O $a)$O p;d};n;bl" $Rm-
+ rm $Rm-
+}
+ftt()(fte "$@"<$tf>$Rm;mv $Rm $tf; cat $Rs $tf>$Rm)
+fborn(){
+ fgr0 "^#ifdef TEST" "^#endif"<$R0|fbn>$tf
+ fgR "^#ifdef TEST_" "^#endif"<$R0 |fgr0 "^#ifdef TEST" "^#endif"|fbn|fte>tests.code
+ fgR "^#ifdef TEST" "^#endif"<$Rs|fbn>$Rm;mv $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh
+}
 fM()(
  valgrind -q --tool=massif --massif-out-file=./vmem.buf --stacks=yes --trace-children=yes $1>/dev/null
  ms_print ./vmem.buf|sed -ne '/[KMG]B/bl;d;:l;/snap/q;p;n;bl';rm ./vmem.buf)
