@@ -87,7 +87,7 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 	
 @_note -
 @_conforming posix-2001+
-@version 2021-07-10 1.2.3
+@version 2021-11-16 1.2.4
 -*/
 
 #ifndef b7b7ab95edd0
@@ -315,7 +315,7 @@ void dbg_b7b7_top(int plv, const char* fname, int nline
 	GLdbgbuffer[0]='\0';
 	snprintf( GLdbgbuffer, orest,
          "DBG: %s %d: %s(): cnt:%d pid:%d arg:(%.*s)\n",
-         fname, nline, fcname, GLdbgcounter, getpid(), strlen(rawstr)-2, rawstr);
+         fname, nline, fcname, GLdbgcounter, getpid(), (int)(strlen(rawstr)-2), rawstr);
 	return;
 }
 
@@ -327,7 +327,7 @@ void dbg_b7b7_middle(int agnum, char* rawlit, ...) {
 	
 	char sbuf[DBG_B7B7_MLEN+1]={0};
 	int orest = DBG_B7B7_MLEN;
-	snprintf( sbuf, orest, "\t%.*s = ", strlen(rawlit)-cutsz, rawlit);
+	snprintf( sbuf, orest, "\t%.*s = ", (int)(strlen(rawlit)-cutsz), rawlit);
 	orest=DBG_B7B7_MLEN - strlen(sbuf);
 
 	va_list vl, vls;
@@ -524,6 +524,10 @@ HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
 /*
  change log
  --
+2021-11-16  Momi-g	<dmy@dmy.dmy>
+
+	* *SH_bn*.h(dbg_b7b7_top, middle): fix for 64bit print(%.*s) >> (int)cast
+
 2021-07-10  Momi-g	<dmy@dmy.dmy>
 
 	* *SH_bn*.h(dbg_middle): add (dbg_b7b7_arg_t){0}, fix b/o read.
