@@ -30,23 +30,23 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 	make man:
 
 	@(code)--
-	~$ amn <<- EEE
+	~$ amn <<- 'EEE'
 	@name hw - hello, world
 	@synopsis hw [-hH] file...
-	@description disp 'hello', '_world'
+	@description disp `hello`, `_world`
 	EEE
 	
-	~$ amn <<- EEE |man /dev/stdin 
+	~$ amn <<- 'EEE' |man /dev/stdin 
 	title=xyz section=3
 	@name hw - hello, world
 	@_syno
 	#include "hw.h"
 	int hw(int ac, char** av);
-	@_desc use c-func parser in @synopsis if section is '_2' or '3'
+	@_desc use c-func parser in @synopsis if section is `_2` or `3`
 	EEE
 	@()--
 
-	read from '_stdin' if ag1 '_file' isnt exist
+	read from `_stdin` if ag1 `_file` isnt exist
 	@(code)
 	~$ anm src.txt
 	~$ anm <src.txt
@@ -59,19 +59,19 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 	-1, -3, -7:	output sample command
 	-D key=str: overwrite default settings
 	@()
-	opt '-D' '_key' are the below. val '_str' \[\abfnrtv], \ooo, \xhh is converted.
+	opt `-D` `_key` are the below. val `_str` \[\abfnrtv], \ooo, \xhh is converted.
 	null-char \0 causes undefined results. 
 	@(pre)@
-	'  mk   ': tag marker. used for charesc too. dfl=@'@@@'
-	'  hlop ': bold/underline highlight block open. dfl=\047 (single quote)
-	'  hlcl ': close. dfl=\047
-	'  ulstr': underline flag. dfl=@'_@'. @'_str@' makes underline, '_str'
-	'  tagop': tag open. @@(pre) etc. dfl=@'(@'
-	'  tagcl': close. dfl=@')@'
-	'  lbdlm': works only in @(list), -a@: info..., etc. dfl=@':@'
-	'  brstr': break marker. dfl=@'--@'. --(\n) works as <br>.
-	'  repnl': replace nl. dfl=  (del). latin-type lang may need \s==\040
-	'  zwsp ': insert zwsp to all chars if set 1. dfl=0 
+	`  mk   `: tag marker. used for charesc too. dfl=@@
+	`  hlop `: bold/underline highlight block open. dfl=@` (back quote)
+	`  hlcl `: close. dfl=\047
+	`  ulstr`: underline flag. dfl=_. @`_str@` makes underline, `_str`
+	`  tagop`: tag open. @@(pre) etc. dfl=(
+	`  tagcl`: close. dfl=)
+	`  lbdlm`: works only in @(list), -a@: info..., etc. dfl=:
+	`  brstr`: break marker. dfl=--. --(\n) works as <br>.
+	`  repnl`: replace nl. dfl=  (del). latin-type lang may need \s==\040
+	`  zwsp `: insert zwsp to all chars if set 1. dfl=0 
 	         man misses locale if read file from local.
 	           ~$ man abc.1		#>> valil, locale=ja_JP etc
 	           ~$ cp /usr/share/man/ja/man1/abc.1.gz ./
@@ -79,18 +79,18 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 	         man preprocesser causes this problem. abc.1.gz is valid.
 	         zwsp temporary improves broken format at editing/making doc.
 	         dont use zwsp to release doc. (h|e|l|l|o ...redundant)
-	         you can resolve this probrem using groff delective '.mso'.
+	         you can resolve this probrem using groff delective `.mso`.
 	           ~$ (echo .mso ja.tmac; cat ./abc.1) | man -l -
-	         `-l -` means ` read local + stdin(-)`. see 'man(1), groff(7)'
+	         `-l -` means `read locale + stdin(-)`. see `man(1), groff(7)`
 	@()
 	--
-	next keys change manpage setting
+	next keys change manpage settings
 	@(pre)@
-	'  title'   : manpage title. dfl=no_title
-	'  section' : man section. dfl=1
-	'  footer'  : dfl isnt set
-	'  footer_l': dfl isnt set
-	'  header'  : dfl isnt set
+	`  title`   : manpage title. dfl=no_title
+	`  section` : man section. dfl=1
+	`  footer`  : dfl isnt set
+	`  footer_l`: dfl isnt set
+	`  header`  : dfl isnt set
 	@()
 @_desc
 	amn converts markup text to manpages. basic rule is close to html.
@@ -108,63 +108,63 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 	  @_syno hw [-h|-H] file ...
 	  @options option list is --
 	    @(list)
-	    -h: escape quote, colon.. @'help@' @: etc
-	    '-v': version
+	    -h: escape quote, colon.. @`help@` @: etc
+	    `-v`: version
 	    @() 
-	  @_see ls(1), 'pwd(1)' '_puts(3)'
+	  @_see ls(1), `pwd(1)` `_puts(3)`
 	---
 	@()--
 	
 	amn accepts the following syntax:
 	@(list)--
-	'_key=str': from BOF to 1st @XXX is defination block. --
+	`_key=str`: from BOF to 1st @XXX is defination block. --
 		- grep only XX=YY str. ignore others --
-		- dont quote. mk=@'@@@' is bad. title=a\101c is valid. --
-		- '_str' is sapareted with sp/tab. use \040 if needs space \s. --
-		- '_str' is converted with printf('_str'). --
-		- option -D'_key=str' overwrites defination block settings.	--
-	'_@XXX': header, '@name' etc. make uppercase. must be BOL.
-		XXX is converted with printf('XXX'). @conforming\040to etc.
+		- dont quote. mk='@' is bad. title=a\101c is valid. --
+		- `_str` is sapareted with sp/tab. use \040 if needs space \s. --
+		- `_str` is converted with printf(`_str`). --
+		- option -D`_key=str` overwrites defination block settings.	--
+	`_@XXX`: header, `@name` etc. make uppercase. must be BOL.
+		XXX is converted with printf(`XXX`). @conforming\040to etc.
 	@_XXX: same as @XXX, but some words are reserved to alias/macros. --
-		'  @_syno '@: @SYNOPSIS		--
-		'  @_opt  '@: @OPTIONS		--
-		'  @_desc '@: @DESCRIPTION	--
-		'  @_eg   '@: @EXSAMPLE		--
-		'  @_ver  '@: @VERSION		--
-		'  @_see  '@: @SEE_ALSO		--
-		'  @_brief'@: add description to @NAME	--
-	'@(pre)...@()': <pre>..</pre>. highlighting, charesc, @@(raw) works
-	'@(code)..@()': similar to @(pre) but any syntax/tag doesnt work
+		`  @_syno `@: @SYNOPSIS		--
+		`  @_opt  `@: @OPTIONS		--
+		`  @_desc `@: @DESCRIPTION	--
+		`  @_eg   `@: @EXSAMPLE		--
+		`  @_ver  `@: @VERSION		--
+		`  @_see  `@: @SEE_ALSO		--
+		`  @_brief`@: add description to @NAME	--
+	`@(pre)...@()`: <pre>..</pre>. highlighting, charesc, @@(raw) works
+	`@(code)..@()`: similar to @(pre) but any syntax/tag doesnt work
 
-	'@(list)..@()': list. splits label and info with colon @'@:@'.
-		if use colon char in infostr, use '@@:' . nl, --(\n) cant use in label. --
-		''eg) it@@'s a 'la'@'_bel': m'sg' @@: --(\n)@(raw).RS@()  ..valid''	--
+	`@(list)..@()`: list. splits label and info with colon '@:'.
+		if use colon char in infostr, use '@@@:' . nl, --(\n) cant use in label. --
+		``eg) it@@`s a `la`@`_bel`: m`sg` @@: --(\n)@(raw).RS@()  ..valid``	--
 
-	'@(list_o)..@()': list for command options. highlight label automatically --
-		''eg) -n, --num[=n]: set num >>>'' '-n', '--num'[='_n'] set num
+	`@(list_o)..@()`: list for command options. highlight label automatically --
+		``eg) -n, --num[=n]: set num >>>`` `-n`, `--num`[=`_n`] set num
 
-	'@(raw)...@()': pass rawstr to groff. no needs to set \n at the block end. --
-		''eg) abc@(raw).SH new_section@()123''
+	`@(raw)...@()`: pass rawstr to groff. no needs to set \n at the block end. --
+		``eg) abc@(raw).SH new_section@()123``
 
-	'@()(\n)': works as block end if exists in the EOL. if block isnt open or
+	`@() + \n`: works as block end if exists in the EOL. if block isnt open or
 		not EOL, ignored/skipped. --
-		''eg) abc@()123 >>> abc123, do nothing''
+		``eg) abc@()123 >>> abc123, do nothing``
 
-	@'str@'		: bold 'str'. keep inner sp/tabs. use '@@@', @@@@' to write '@', @@'
-	@'_str@'	: underline '_str'. 1 char @'_@' works as bold
-	@'@'str@'@'	: single quote x2, no highlighting. you dont need esc quote. --
-		''eg) '@' 'abc' esc @@' @@@@ works too'@''' >>'' 'abc' esc ' @@ works too''
-	'@@@''	: single quote. you can also use groff esc '@(raw) \(aa @()'
-	'@@@@'	: atmark. you can also use groff '@(raw) @ @()'
-	'@@:'	: colon. maybe uses only for @(list) or @(list_o). '@(raw) : @()'
-	'--(\n)': 2-hyphen + nl. <br>. --(\s)(\n) doesnt work. 'gnu_man' seems
-		to merge blanklines at output, so you cant use multi-blankslines. --
+	@`str@`		: bold `str`. keep inner sp/tabs. use `@@@`, @@@@` to write `@`, @@`
+	@`_str@`	: underline `_str`. 1 char @`_@` works as bold
+	@`@`str@`@`	: backquote x2, no highlighting. you dont need esc quote. --
+		``eg) `@` `abc` esc @@` @@@@ works too`@``` >>`` `abc` esc ` @@ works too``
+	`@@@``	: back quote. you can also use groff esc `@(raw) \(ga @()`
+	`@@@@`	: atmark. you can also use groff `@(raw) @ @()`
+	`@@:`	: colon. maybe uses only for @(list) or @(list_o). `@(raw) : @()`
+	`--(\n)`: 2-hyphen + nl. <br>. --(\s)(\n) doesnt work. `gnu_man` seems
+		to merge blanklines at output, so you cant use multi-blanklines. --
 	@()
 
 	if @@(pre,code,list,list_o) end with @@(...)\n, deletes \n char. --
 	if they end with @@(...)--\n, add a empty line before the block. --
 	if @@(pre,code) block end with @@(...)@@\n, remove the leading tabs as
-	shell heredoc '' '<<-' '' syntax. --
+	shell heredoc `` `<<-` `` syntax. --
 	if they end with @@(...)--@\n, add a empty lines and remove the leading tabs.	--
 	if @@() end with @@()--\n or @@()--@@\n, add a empty line after block.	--
 	if @@() end with @@()@@\n, work the same as @@()\n. (ignores end @@). --
@@ -188,11 +188,11 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 
 	the @(list_o) label and @SYNOPSIS block are highlighted automatically.
 	@@(list_o) label is assumed to be command options -a, --all[=str] etc. --
-	@SYNOPSIS parser is changed by '-Dsection'='_num' setting
+	@SYNOPSIS parser is changed by `-Dsection`=`_num` setting
 	@(list)
 	section 1:	detect command format, "cmd [-a ag] file" etc. use --(\n)
 		to split long command description@: --
-		'    'eg) cmd [-a ag] --(\n)(\t) [-b] file
+		`    `eg) cmd [-a ag] --(\n)(\t) [-b] file
 	section 2/3: detect C-func decreations "int myf(int num);" etc. use 
 		simple (\n) to split long string. (allow --(\n) too)--
 		this block works as @@(pre) block with C-func highlighting.
@@ -205,14 +205,14 @@ repnl=\040	//dfl is repnl =(noset). change nl to \s for latin-langages
 		@name hw - hello, world
 		@_desc disp --
 		  @(raw)...@() 
-		  'messages' ...
+		  `messages` ...
 		
 		--
 		mk=#_@ brstr=???
 		#_@name hw - hello, world
 		#_@_desc disp ???
 		  #_@(raw)...#_@() 
-		  'messages' ...
+		  `messages` ...
 	@()--@
 
 @conforming_to	posix-sh, POSIX.1-2001+
@@ -225,7 +225,7 @@ if you needs to html converter, use mandoc.
 gnu_man has self html parser (man -H) but not so good 
  ~$ cat amn.1 |man -Hcat /dev/stdin > amn.1.html
 
-if you needs plaintext, man or mandoc.
+if you needs plaintext, use man or mandoc.
  ~$ mandoc -Tutf8 <amn.1 | sed -e "s/.`printf '\\b'`//g"> amn.1.txt
  ~$ amn -7|amn -Dzwsp=1 |
 		man -Tutf8 /dev/stdin|sed -e "s/.`printf '\\b'`//g"> amn.7.txt
@@ -235,18 +235,19 @@ if you needs plaintext, man or mandoc.
 	Copyright (C) 2021 Momi-g --
 	License GPLv3+ <https://gnu.org/licenses/gpl.html>.
 
+@_ver 2021-12-02 v1.1.1
 @_see
-	'man-pages(7)', 'groff_man(7)', 'groff(7)', 'mandoc(1)'	--
-	https://wiki.archlinux.org/title/Man_page (strongly recommend)	--
+	`man-pages(7)`, `groff_man(7)`, `groff(7)`, `mandoc(1)`	--
+	https://wiki.archlinux.org/title/Man_page --
 	--
-	...recommend to read man-pages(7)
+	...recommend to read man-pages(7), arch_wiki
 #SH_docE
 EEE
 version_info(){
 cat << 'EEE'
-amn v1.0.3
+amn v1.1.1
 Copyright (C) 2021 Momi-g
-License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
+License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>
 EEE
 exit 0
 }
@@ -258,16 +259,16 @@ opt: -hH(elp), -V(er), -D(ef), -137(sample output)
 ---
 eg) ~$ amn -1	#>> copy & run output code 
    
-    ~$ echo "
-@name myapp - amn     'ignores' '_blanks'/nl same as html
+    ~$ echo '
+@name myapp - amn     `ignores` `_blanks`/nl same as html
 @synopsis mycomm [-a|-b] [-d word] words
-	" | amn | man /dev/stdin
+	' | amn | man /dev/stdin
 
  amn makes a manpage from plain text. syntax is:
     @str   : section header, .SH, <h2> etc. set to BOL
-    'str'  : bold (and you can use as space holder, '  str')
-    '_str' : underline
-    ''str'': no highlight. ''it's good'' == it@'s good
+    `str`  : bold (and you can use as space holder, `  str`)
+    `_str` : underline
+    ``str``: no highlight. ``it`s good`` == it@`s good
     --(\n) : break, <br>. amn skips newline and tab
     @(...) : other format/setting tag
 
@@ -292,19 +293,19 @@ SYNOPSIS
 TL;DR
        make man:
 
-            ~$ amn <<- EEE
+            ~$ amn <<- 'EEE'
             @name hw - hello, world
             @synopsis hw [-hH] file...
-            @description disp "hello", "_world"
+            @description disp `hello`, `_world`
             EEE
 
-            ~$ amn <<- EEE |man /dev/stdin
+            ~$ amn <<- 'EEE' |man /dev/stdin
             title=xyz section=3
             @name hw - hello, world
             @_syno
             #include "hw.h"
             int hw(int ac, char** av);
-            @_desc use c-func parser in @synopsis if section is "_2" or "3"
+            @_desc use c-func parser in @synopsis if section is `_2` or `3`
             EEE
 
        read from stdin if ag1 file isnt exist
@@ -326,14 +327,14 @@ OPTIONS
 
        opt -D key are the below. val str \[\abfnrtv], \ooo, \xhh is converted.
        null-char \0 causes undefined results.
-         mk   : tag marker. used for charesc too. dfl='@'
-         hlop : bold/underline highlight block open. dfl=\047 (single quote)
+         mk   : tag marker. used for charesc too. dfl=@
+         hlop : bold/underline highlight block open. dfl=` (back quote)
          hlcl : close. dfl=\047
-         ulstr: underline flag. dfl='_'. '_str' makes underline, str
-         tagop: tag open. @(pre) etc. dfl='('
-         tagcl: close. dfl=')'
-         lbdlm: works only in @(list), -a: info..., etc. dfl=':'
-         brstr: break marker. dfl='--'. --(\n) works as <br>.
+         ulstr: underline flag. dfl=_. `_str` makes underline, str
+         tagop: tag open. @(pre) etc. dfl=(
+         tagcl: close. dfl=)
+         lbdlm: works only in @(list), -a: info..., etc. dfl=:
+         brstr: break marker. dfl=--. --(\n) works as <br>.
          repnl: replace nl. dfl=  (del). latin-type lang may need \s==\040
          zwsp : insert zwsp to all chars if set 1. dfl=0
                 man misses locale if read file from local.
@@ -345,9 +346,9 @@ OPTIONS
                 dont use zwsp to release doc. (h|e|l|l|o ...redundant)
                 you can resolve this probrem using groff delective .mso.
                   ~$ (echo .mso ja.tmac; cat ./abc.1) | man -l -
-                `-l -` means ` read local + stdin(-)`. see man(1), groff(7)
+                -l - means read locale + stdin(-). see man(1), groff(7)
 
-       next keys change manpage setting
+       next keys change manpage settings
          title   : manpage title. dfl=no_title
          section : man section. dfl=1
          footer  : dfl isnt set
@@ -368,10 +369,10 @@ DESCRIPTION
          @_syno hw [-h|-H] file ...
          @options option list is --
            @(list)
-           -h: escape quote, colon.. @"help@" @: etc
-           "-v": version
+           -h: escape quote, colon.. @`help@` @: etc
+           `-v`: version
            @()
-         @_see ls(1), "pwd(1)" "_puts(3)"
+         @_see ls(1), `pwd(1)` `_puts(3)`
        ---
 
        amn accepts the following syntax:
@@ -407,8 +408,8 @@ DESCRIPTION
 
        @(list)..@()
               list. splits label and info with colon ':'. if use colon char in
-              infostr, use @: . nl, --(\n) cant use in label.
-              eg) it@"s a "la"'_bel": m"sg" @: --(\n)@(raw).RS@()  ..valid
+              infostr, use '@:' . nl, --(\n) cant use in label.
+              eg) it@`s a `la``_bel`: m`sg` @: --(\n)@(raw).RS@()  ..valid
 
 
        @(list_o)..@()
@@ -419,33 +420,33 @@ DESCRIPTION
               pass rawstr to groff. no needs to set \n at the block end.
               eg) abc@(raw).SH new_section@()123
 
-       @()(\n)
+       @() + \n
               works as block end if exists in the EOL. if block isnt  open  or
               not EOL, ignored/skipped.
               eg) abc@()123 >>> abc123, do nothing
 
-       'str'  bold str. keep inner sp/tabs. use @', @@ to write ', @
+       `str`  bold str. keep inner sp/tabs. use @`, @@ to write `, @
 
-       '_str' underline str. 1 char '_' works as bold
+       `_str` underline str. 1 char `_` works as bold
 
-       ''str''
-              single quote x2, no highlighting. you dont need esc quote.
-              eg) "' "abc" esc @" @@ works too"' >> "abc" esc " @ works too
+       ``str``
+              backquote x2, no highlighting. you dont need esc quote.
+              eg) `` `abc` esc @` @@ works too`` >> `abc` esc ` @ works too
 
-       @'     single quote. you can also use groff esc @(raw) \(aa @()
+       @`     back quote. you can also use groff esc @(raw) \(ga @()
 
        @@     atmark. you can also use groff @(raw) @ @()
 
        @:     colon. maybe uses only for @(list) or @(list_o). @(raw) : @()
 
        --(\n) 2-hyphen  +  nl.  <br>. --(\s)(\n) doesnt work. gnu_man seems to
-              merge blanklines at output, so you cant use multi-blankslines.
+              merge blanklines at output, so you cant use multi-blanklines.
 
 
        if @(pre,code,list,list_o) end with @(...)\n, deletes \n char.
        if they end with @(...)--\n, add a empty line before the block.
        if @(pre,code) block end with @(...)@\n, remove  the  leading  tabs  as
-       shell heredoc  "<<-"  syntax.
+       shell heredoc  `<<-`  syntax.
        if  they end with @(...)--@\n, add a empty lines and remove the leading
        tabs.
        if @() end with @()--\n or @()--@\n, add a empty line after block.
@@ -487,14 +488,14 @@ EXSAMPLE
        @name hw - hello, world
        @_desc disp --
          @(raw)...@()
-         "messages" ...
+         `messages` ...
 
        --
        mk=#_@ brstr=???
        #_@name hw - hello, world
        #_@_desc disp ???
          #_@(raw)...#_@()
-         "messages" ...
+         `messages` ...
 
 
 
@@ -509,10 +510,10 @@ NOTES
        gnu_man has self html parser (man -H) but not so good
         ~$ cat amn.1 |man -Hcat /dev/stdin > amn.1.html
 
-       if you needs plaintext, man or mandoc.
-        ~$ mandoc -Tutf8 <amn.1 | sed -e "s/.`printf "\\b"`//g"> amn.1.txt
+       if you needs plaintext, use man or mandoc.
+        ~$ mandoc -Tutf8 <amn.1 | sed -e "s/.`printf '\\b'`//g"> amn.1.txt
         ~$ amn -7|amn -Dzwsp=1 |
-                 man -Tutf8 /dev/stdin|sed -e "s/.`printf "\\b"`//g"> amn.7.txt
+                 man -Tutf8 /dev/stdin|sed -e "s/.`printf '\\b'`//g"> amn.7.txt
         (-Dzwsp=1 + man makes terminal 80x24 suitable text in multibyte locale)
 
 
@@ -520,11 +521,14 @@ COPYRIGHT
        Copyright (C) 2021 Momi-g
        License GPLv3+ <https://gnu.org/licenses/gpl.html>.
 
+VERSION
+       2021-12-02 v1.1.1
+
 SEE_ALSO
        man-pages(7), groff_man(7), groff(7), mandoc(1)
-       https://wiki.archlinux.org/title/Man_page (strongly recommend)
+       https://wiki.archlinux.org/title/Man_page
 
-       ...recommend to read man-pages(7)
+       ...recommend to read man-pages(7), arch_wiki
 
 
 
@@ -607,8 +611,8 @@ BEGIN{
 #print(amn_cfunc)>"/dev/stderr"
 	split("", darr)
 	darr["mk"]   = "@"		#cmn_mk
-	darr["hlop"]= "\047"	#cmn_hlop
-	darr["hlcl"]= "\047"	#cmn_hlcl
+	darr["hlop"]= "`"		#cmn_hlop
+	darr["hlcl"]= "`"		#cmn_hlcl
 	darr["tagop"]= "("		#cmn_tagop
 	darr["tagcl"]= ")"		#cmn_tagcl
 	darr["lbdlm"]= ":"		#cmn_tagcl
@@ -793,8 +797,8 @@ EEE
 
 usage_1(){
 cat << 'EEE'
-./amn <<- E | man /dev/stdin 
-@name myapp - amn     'ignores' '_blanks'/nl same as html
+./amn <<- 'E' | man /dev/stdin 
+@name myapp - amn     `ignores` `_blanks`/nl same as html
 @synopsis mycomm [-a|-b] [-d word] words...
 E
 
@@ -807,8 +811,8 @@ usage_3(){
 cat << 'EEE'
 ./amn <<- E | man /dev/stdin
 title=hellword section=3
-@name hw - use C-func parser to @synopsis if section is '_2' or '3'
-@_syno int hw(int ac, char** av); //write '_anymsg'
+@name hw - use C-func parser to @synopsis if section is `_2` or `3`
+@_syno int hw(int ac, char** av); //write `_anymsg`
 E
 
 #...copy & run upper code
@@ -827,7 +831,7 @@ repnl=	//nl削除デフォルトを使用
 		- javadocコメントのような簡潔な記述を
 		- latin系以外の文字でも記載できて
 		- roffという標準的なシステムで処理して
-		- プログラマのdoc作成の'_労力を最小限'に
+		- プログラマのdoc作成の`_労力を最小限`に
 	@()--
 	することが目的です。そのためにamnは
 	@(pre)--@
@@ -852,7 +856,7 @@ repnl=	//nl削除デフォルトを使用
 	manはマクロ事前定義によりある程度簡単に扱えるが、それでも太字指定など
 	面倒な記述が多い。--
 	amnは--
-	'	' plain text >> amn内部パーサ >> manマクロ >> groff言語 --
+	`	` plain text >> amn内部パーサ >> manマクロ >> groff言語 --
 	と変換して冗長な記述を不要にしている。既存のapp不採用の理由は
 	@(list)--
 	- html: 不要タグが多すぎ、記述が冗長。外部htmlパーサが必要
@@ -929,7 +933,7 @@ E
 
 exdir=`readlinkp -f "$0"`
 exdir=$(dirname "$exdir")
-amn_main "$@"
+amn_main "$@"	#SH_MAIN
 
 # ./amn -H|./amn| mandoc -Tpdf > amn_1.pdf
 
@@ -938,6 +942,14 @@ amn_main "$@"
 cat<<'EEE'>/dev/null
  change log
  --
+2021-12-02	Momi-g	<dmy@dmy.dmy>
+
+	* amn(amn) : fix 64bit, build script, doc. v1.1.1
+
+2021-09-23	Momi-g	<dmy@dmy.dmy>
+
+	* amn(amn) : v1.1.0. change dfl highlight ' >> `
+
 2021-08-27	Momi-g	<dmy@dmy.dmy>
 
 	* amn(amn) : import brp format
